Module drawable_descriptor

Module drawable_descriptor 

Available on crate feature api-12 only.

Structs

ArkUI_DrawableDescriptor
Defines the drawable descriptor.
ArkUI_DrawableDescriptor_AnimationControllerapi-22
Defines the animation controller of arkui drawable descriptor.
DrawableDescriptor_AnimationStatusapi-22
Defines the animation status of the drawable descriptor.
OH_PixelmapNative

Functions

OH_ArkUI_DrawableDescriptor_CreateAnimationControllerapi-22
Obtains the animation controller.
OH_ArkUI_DrawableDescriptor_CreateFromAnimatedPixelMap
Creates a DrawableDescriptor from a Pixelmap array.
OH_ArkUI_DrawableDescriptor_CreateFromPixelMap
Creates a DrawableDescriptor from a Pixelmap.
OH_ArkUI_DrawableDescriptor_Dispose
Destroys the pointer to the drawableDescriptor.
OH_ArkUI_DrawableDescriptor_DisposeAnimationControllerapi-22
Releases the animation controller.
OH_ArkUI_DrawableDescriptor_GetAnimatedPixelMapArray
Obtains the Pixelmap array used to play the animation.
OH_ArkUI_DrawableDescriptor_GetAnimatedPixelMapArraySize
Obtains the size of the Pixelmap array used to play the animation.
OH_ArkUI_DrawableDescriptor_GetAnimationAutoPlayapi-22
Obtains whether to play the animation automatically.
OH_ArkUI_DrawableDescriptor_GetAnimationDuration
Obtains the total playback duration.
OH_ArkUI_DrawableDescriptor_GetAnimationFrameDurationsapi-22
Obtains the frame duration array.
OH_ArkUI_DrawableDescriptor_GetAnimationIteration
Obtains the number of playback times.
OH_ArkUI_DrawableDescriptor_GetAnimationStatusapi-22
Obtains the animation playback status.
OH_ArkUI_DrawableDescriptor_GetStaticPixelMap
Obtains the Pixelmap object.
OH_ArkUI_DrawableDescriptor_PauseAnimationapi-22
Pauses the animation at the current frame.
OH_ArkUI_DrawableDescriptor_ResumeAnimationapi-22
Resumes the animation at the current frame.
OH_ArkUI_DrawableDescriptor_SetAnimationAutoPlayapi-22
Sets whether to play the animation automatically.
OH_ArkUI_DrawableDescriptor_SetAnimationDuration
Sets the total playback duration.
OH_ArkUI_DrawableDescriptor_SetAnimationFrameDurationsapi-22
Sets the frame duration array.
OH_ArkUI_DrawableDescriptor_SetAnimationIteration
Sets the number of playback times.
OH_ArkUI_DrawableDescriptor_StartAnimationapi-22
Starts the animation from first frame.
OH_ArkUI_DrawableDescriptor_StopAnimationapi-22
Stops the animation and back to first frame.

Type Aliases

OH_PixelmapNativeHandle
Defines the pointer to OH_PixelmapNative.