OH_ArkUI_Swiper_IsFakeDragging

Function OH_ArkUI_Swiper_IsFakeDragging 

pub unsafe extern "C" fn OH_ArkUI_Swiper_IsFakeDragging(
    node: ArkUI_NodeHandle,
    isFakeDragging: *mut bool,
) -> i32
Available on crate features api-12 and api-23 only.
Get the fake drag state of the Swiper node.

Arguments

  • node - ArkUI_NodeHandle pointer.

  • isFakeDragging - If a fake drag is in progress return true, otherwise return false

Returns

  • Error code. [ARKUI_ERROR_CODE_NO_ERROR] Success. [ARKUI_ERROR_CODE_PARAM_INVALID] Function parameter exception.

Available since API-level: 23