OH_ArkUI_Swiper_StartFakeDrag

Function OH_ArkUI_Swiper_StartFakeDrag 

pub unsafe extern "C" fn OH_ArkUI_Swiper_StartFakeDrag(
    node: ArkUI_NodeHandle,
    isSuccessful: *mut bool,
) -> i32
Available on crate features api-12 and api-23 only.
Start a fake drag of the Swiper node. Call OH_ArkUI_Swiper_FakeDragBy to simulate the drag motion. Call OH_ArkUI_Swiper_StopFakeDrag to complete the fake drag. A fake drag can be interrupted by a real drag. If you need to ignore touch events and other user input during a fake drag, use NODE_SWIPER_DISABLE_SWIPE.

Arguments

  • node - ArkUI_NodeHandle pointer.

  • isSuccessful - If the fake drag started successfully, return true. If the Swiper is not ready to start the fake drag, or a real or fake drag is already in progress, return false.

Returns

  • Error code. [ARKUI_ERROR_CODE_NO_ERROR] Success. [ARKUI_ERROR_CODE_PARAM_INVALID] Function parameter exception.

Available since API-level: 23