#[repr(C)]pub struct ArkUI_AttributeItem {
pub value: *const ArkUI_NumberValue,
pub size: i32,
pub string: *const c_char,
pub object: *mut c_void,
}Available on crate feature
api-12 only.Expand description
Defines the general input parameter structure of the [setAttribute] function. The property
setting interfaces can utilize the member variables within it to store data of specific parameter types.
Available since API-level: 12
Fields
value: *const ArkUI_NumberValueA number array, used to store parameters of the number array type.
size: i32The size of the number array, used together with the variable value, indicating the length of the value array.
string: *const c_charString type, used to store parameters of the string type.
object: *mut c_voidObject type, used to store parameters of the object type.