Module native_type

Module native_type 

Available on crate feature api-12 only.

Structs

ARKUI_TextPickerCascadeRangeContent
Defines the input structure of the interconnected multi-column text picker.
ARKUI_TextPickerRangeContent
Defines the input structure of the single-column text picker with image resources.
AbilityBase_Wantapi-20
Declares the Ability base want.
ArkUI_AccessibilityActionType
Define accessible action types.
ArkUI_AccessibilityCheckedState
Defines the state type for the accessibility checkbox.
ArkUI_AccessibilityMode
Enumerates the accessibility modes.
ArkUI_AccessibilityState
Defines the accessibility state for the component.
ArkUI_AccessibilityValue
Defines the accessibility value for the component.
ArkUI_ActiveChildrenInfoapi-14
Define ActiveChildenInfo class information.
ArkUI_AdaptiveColor
Enumerates the adaptive color modes.
ArkUI_Alignment
Enumerates the alignment modes.
ArkUI_AlignmentRuleOption
specifies the alignment rules for subcomponents set in relative containers.
ArkUI_AnimationCurve
Enumerates the animation curves.
ArkUI_AnimationDirection
Enumerates the animation playback modes.
ArkUI_AnimationFillMode
Defines the status before and after execution of the animation in the current playback direction.
ArkUI_AnimationPlayMode
Enumerates the animation playback modes.
ArkUI_AnimationStatus
Defines the playback status for the image animator.
ArkUI_Axis
Enumerates the scroll directions for the component.
ArkUI_BarStateapi-22
Enumerates the status of the scroll bar.
ArkUI_BarrierDirection
defines the direction of the barrier line.
ArkUI_BarrierOption
barrier parameter, used to define the id, direction and components of the barrier that it depends on when generating it.
ArkUI_BlendApplyType
Defines how the specified blend mode is applied.
ArkUI_BlendMode
Enumerates the blend modes.
ArkUI_BlurStyle
Enumerates the blur styles.
ArkUI_BlurStyleActivePolicyapi-19
Enumerates the activation policies for the background blur effect.
ArkUI_BorderStyle
Enumerates the border styles.
ArkUI_ButtonType
Enumerates the button types.
ArkUI_CalendarAlignment
Enumerates the alignment modes between the calendar picker and the entry component.
ArkUI_CancelButtonStyle
Enumerates the styles of the Cancel button.
ArkUI_CheckboxShape
Enumerates the shapes of the check box
ArkUI_ClipType
Enumerates the clipping region types.
ArkUI_ColorMode
Enumerates the color modes.
ArkUI_ColorStop
Defines the gradient color stop structure.
ArkUI_ColorStrategy
Enumerates the foreground colors.
ArkUI_ContentClipModeapi-18
Enumerates the content clipping modes of scrollable components.
ArkUI_ContentTransitionEffectapi-21
Set the types and parameters related to content transition effects.
ArkUI_ContextCallback
Defines the event callback type.
ArkUI_CopyOptions
Enumerates the text copy and paste modes.
ArkUI_CornerDirectionapi-20
Enumerates the corner derection.
ArkUI_CrossLanguageOptionapi-15
The cross-language option.
ArkUI_CustomPropertyapi-14
Define the information of the Custom Property class for custom properties.
ArkUI_CustomSpanDrawInfo
Defines a struct for the drawing information of a custom span.
ArkUI_CustomSpanMeasureInfo
Defines a struct for the measurement information of a custom span.
ArkUI_CustomSpanMetrics
Defines a struct for the measurement metrics of a custom span.
ArkUI_DatePickerModeapi-18
Enumerates the modes of the date picker.
ArkUI_Direction
Enumerates the modes in which components are laid out along the main axis of the container.
ArkUI_DrawContext
Defines the structure of the component drawing context.
ArkUI_DynamicRangeModeapi-21
Enumerates the image dynamic range mode.
ArkUI_EdgeDirectionapi-20
Enumerates the edge derection.
ArkUI_EdgeEffect
Enumerates the effects used at the edges of the component when the boundary of the scrollable content is reached.
ArkUI_EffectEdgeapi-18
Enumerates the edges for which the effect takes effect when the boundary of the scrollable content is reached.
ArkUI_EllipsisMode
Enumerates the ellipsis positions.
ArkUI_EmbeddedComponentOptionapi-20
Define the EmbeddedComponentOption for the EmbeddedComponent.
ArkUI_EnterKeyType
Enumerates the types of the Enter key for a single-line text box.
ArkUI_ExpandModeapi-15
Enumerates the expand modes.
ArkUI_FinishCallbackType
Enumerates the animation onFinish callback types.
ArkUI_FlexAlignment
Enumerates the vertical alignment modes.
ArkUI_FlexDirection
Enumerates the directions of the main axis in the flex container.
ArkUI_FlexWrap
Defines whether the flex container has a single line or multiple lines.
ArkUI_FocusMoveapi-18
Define an enum for the focus movement directions.
ArkUI_FocusPriorityapi-23
Enumerates the priority levels for focus management within the application. These levels determine the sequence in which UI components receive focus during user interaction.
ArkUI_FocusWrapModeapi-20
Enumerates the focus wrap mode of components.
ArkUI_FontStyle
Enumerates the font styles.
ArkUI_FontWeight
Enumerates the font weights.
ArkUI_GridItemAlignmentapi-22
Enumerates the grid item alignment modes.
ArkUI_GridItemRectapi-22
Defines the return value structure for the onGetRectByIndex callback in Grid layout options.
ArkUI_GridItemSizeapi-22
Defines the return value structure for the onGetIrregularSizeByIndex callback in Grid layout options.
ArkUI_GridItemStyleapi-22
Enumerates styles of grid items.
ArkUI_GridLayoutOptionsapi-22
Defines the Grid layout options.
ArkUI_GuidelineOption
guideLine parameters, used to define the id, direction and position of the guideline.
ArkUI_HitTestMode
Enumerates the hit test modes.
ArkUI_HorizontalAlignment
Enumerates the alignment mode in the horizontal direction.
ArkUI_HostWindowInfoapi-15
Define the information of the HostWindowInfo class for window properties.
ArkUI_HoverEffectapi-23
Enumerates the hover effects when a component is hovered over.
ArkUI_HoverModeAreaTypeapi-15
defines the enumerated value of area in hover mode.
ArkUI_ImageAnimatorFrameInfo
Defines the image frame.
ArkUI_ImageInterpolation
Enumerates the image interpolation effect.
ArkUI_ImageRenderMode
Enumerates the image rendering modes.
ArkUI_ImageRepeat
Enumerates the image repeat patterns.
ArkUI_ImageRotateOrientationapi-21
Enumerates the image rotate orientation.
ArkUI_ImageSize
Defines the image size.
ArkUI_ImageSpanAlignment
Enumerates the alignment mode of the image with the text.
ArkUI_IntOffset
Describes the position of a component.
ArkUI_IntSize
Describes the width and height of a component.
ArkUI_ItemAlignment
Enumerates the modes in which components are laid out along the cross axis of the container.
ArkUI_ItemFillPolicyapi-22
Specifies the number of columns for different responsive breakpoint specifications.
ArkUI_KeyboardAppearanceapi-15
Defines the keyboard style of input box
ArkUI_KeyboardAvoidModeapi-15
defines the enumerated value of the customDialog’s keyboard avoid mode.
ArkUI_LayoutConstraint
Sets the size constraints of a component during component layout.
ArkUI_LayoutPolicyapi-21
Enumerates the LayoutPolicy.
ArkUI_LayoutSafeAreaEdgeapi-23
Define the edges for expanding the safe area in layout.
ArkUI_LayoutSafeAreaTypeapi-23
Define the types for expanding the safe area in layout.
ArkUI_LengthMetricUnit
Enumerates the component units.
ArkUI_LinearGradientDirection
Enumerates the gradient directions.
ArkUI_ListChildrenMainSize
Define the ChildrenMainSize class information for a List.
ArkUI_ListItemAlignment
Enumerates the alignment modes of items along the cross axis.
ArkUI_ListItemGroupAreaapi-15
Define an enum for the areas of the ListItemGroup component.
ArkUI_ListItemSwipeActionDirectionapi-21
Define the direction to expand the swipe action.
ArkUI_ListItemSwipeActionItem
Define the configuration information of the Item within the ListitemSwipeActionOption method.
ArkUI_ListItemSwipeActionOption
Define the configuration information for the ListitemSwipeActionOption method.
ArkUI_ListItemSwipeActionState
Define the pattern of element arrangement in the main axis direction of the Swiper component.
ArkUI_ListItemSwipeEdgeEffect
Define the explicit and implicit mode of the SwipeAction method for the Listitem component.
ArkUI_LocalizedAlignmentapi-23
Enumerates the localizedAlignment modes.
ArkUI_Margin
Describes the margins of a component.
ArkUI_MarqueeStartPolicyapi-23
Enumerates the MarqueeStartPolicy.
ArkUI_MarqueeUpdatePolicyapi-23
Enumerates the MarqueeUpdatePolicy.
ArkUI_MaskType
Enumerates the mask types.
ArkUI_MenuPolicyapi-23
Menu pop-up strategy.
ArkUI_MotionPathOptionsapi-23
Defines the motion path options for path animation.
ArkUI_NativeDialog
Defines the custom dialog box controller of ArkUI on the native side.
ArkUI_NavDestinationState
Defines the state of the NavDestination component.
ArkUI_Node
ArkUI_NodeContent
ArkUI_ObjectFit
Defines how the image is resized to fit its container. ImageSpanAlignment
ArkUI_PageFlipModeapi-15
Enumerates the page flipping modes using the mouse wheel for the Swiper component.
ArkUI_PickerIndicatorBackgroundapi-23
Style parameters of background indicator.
ArkUI_PickerIndicatorDividerapi-23
Style parameters of divider indicator.
ArkUI_PickerIndicatorStyleapi-23
Definition of indicator style.
ArkUI_PickerIndicatorTypeapi-23
Enumerates the selected indicator type of picker.
ArkUI_PixelRoundCalcPolicyapi-21
Enumerates the PixelRoundPolicy.
ArkUI_PixelRoundPolicyapi-21
Defines the PixelRound policy of a component’s four edges.
ArkUI_PositionEdgesapi-21
Define the Edges describing the position of a component by distances to the container’s four edges.
ArkUI_ProgressLinearStyleOptionapi-15
Set the linear progress indicator style.
ArkUI_ProgressType
Enumerates the styles of the progress indicator.
ArkUI_Rect
Defines a mask area.
ArkUI_RelativeLayoutChainStyle
defines the style of the chain.
ArkUI_RenderFit
Enumerates the render fit.
ArkUI_RenderStrategyapi-23
Enumerates the graphics rendering strategy.
ArkUI_ResponseRegionSupportedToolapi-23
Enumerates the input tool types supported for response region configuration.
ArkUI_RotationOptions
Defines the rotation options for component transition.
ArkUI_RouterPageState
Define the state of Router Page.
ArkUI_SafeAreaEdge
defines the enumerated value of the direction of the extended security zone.
ArkUI_SafeAreaType
defines the enumerated value of the extended security zone.
ArkUI_ScaleOptions
Defines the scaling options for component transition.
ArkUI_ScrollAlignment
Alignment when scrolling to specific items.
ArkUI_ScrollBarDisplayMode
Enumerates the scrollbar display modes.
ArkUI_ScrollDirection
Enumerates the scroll directions for the component.
ArkUI_ScrollEdge
Defines the edge to which the component scrolls.
ArkUI_ScrollNestedMode
Defines nested scrolling options.
ArkUI_ScrollSnapAlign
Enumerates the alignment modes of list items when scrolling ends.
ArkUI_ScrollSnapAnimationSpeedapi-22
Enumerates the scroll snap animation speeds for lists.
ArkUI_ScrollSource
Define the rolling source enumeration value.
ArkUI_ScrollState
Define the current scrolling state.
ArkUI_SelectedDragPreviewStyleapi-23
Defines the selected drag preview style configuration.
ArkUI_SelectionOptionsapi-23
Defines the options for selection operation.
ArkUI_ShadowStyle
Enumerates the shadow styles.
ArkUI_ShadowType
Enumerates the shadow types.
ArkUI_ShapeType
Enumerates the custom shapes.
ArkUI_ShowCounterConfigapi-22
Defines the textField’s counter configuration.
ArkUI_SliderBlockStyle
Enumerates the types of the slider in the block direction.
ArkUI_SliderDirection
Enumerates the scroll directions of the slider.
ArkUI_SliderStyle
Enumerates the slider styles.
ArkUI_SnapshotOptionsapi-15
Defines the options for taking snapshot.
ArkUI_StickyStyle
Enumerates the modes for pinning the header to the top or the footer to the bottom.
ArkUI_StyledString_Descriptorapi-14
Define the data objects of styled string supported by text components.
ArkUI_SwiperAnimationModeapi-15
Enumerates the animation modes for [NODE_SWIPER_INDEX].
ArkUI_SwiperArrow
Enumerates arrow styles of the navigation point indicator.
ArkUI_SwiperArrowStyleapi-19
Defines the arrow style for the swiper.
ArkUI_SwiperDigitIndicatorapi-19
Defines the digital indicator style for the swiper.
ArkUI_SwiperIndicator
Defines the navigation indicator style for the swiper.
ArkUI_SwiperIndicatorType
Define the navigation indicator type of the swiper.
ArkUI_SwiperNestedScrollMode
Nested scrolling mode for Swiper components and parent components.
ArkUI_SystemColorMode
Enumerates the system color modes.
ArkUI_SystemFontStyleEvent
Defines parameter used by the system font style callback event.
ArkUI_TextAlignment
Enumerates the text alignment mode.
ArkUI_TextAreaType
Enumerates the text box types.
ArkUI_TextCascadePickerRangeContentArrayapi-19
TextPicker multi column selector, supports mixing text and images.
ArkUI_TextCase
Enumerates the text cases.
ArkUI_TextContentAlignapi-21
Enumerates text content align styles.
ArkUI_TextContentBaseControllerapi-23
Defines the text content base controller.
ArkUI_TextCopyOptions
Defines whether copy and paste is allowed for text content.
ArkUI_TextDataDetectorType
Defines the entity type for text recognition.
ArkUI_TextDecorationStyle
Enumerates the text decoration styles.
ArkUI_TextDecorationType
Enumerates the text decoration types.
ArkUI_TextDirectionapi-23
Enumerates the text text direction.
ArkUI_TextEditMenuOptionsapi-22
Defines the text menu item for edit menu options.
ArkUI_TextHeightAdaptivePolicy
Defines how the adaptive height is determined for the text.
ArkUI_TextInputContentType
Enumerates the autofill types.
ArkUI_TextInputStyle
Defines the text input style.
ArkUI_TextInputType
Enumerates the text input types.
ArkUI_TextMarqueeOptionsapi-23
Defines the marquee options of text.
ArkUI_TextMenuItemapi-22
Defines the text menu item for edit menu item.
ArkUI_TextMenuItemArrayapi-22
Defines text menu item array.
ArkUI_TextMenuItemIdapi-22
Enumerates the text menu item id.
ArkUI_TextOverflow
Enumerates the display modes when the text is too long.
ArkUI_TextPickerRangeContentArrayapi-19
TextPicker single column selector, supports mixing text and images.
ArkUI_TextPickerRangeType
Enumerates the types of the text picker.
ArkUI_TextResponseTypeapi-22
Enumerates the text response type.
ArkUI_TextSelectionMenuOptionsapi-22
Defines the selection menu.
ArkUI_TextSpanTypeapi-22
Enumerates the text span type.
ArkUI_TextVerticalAlignmentapi-20
Enumerates text vertical alignment styles.
ArkUI_TransitionEdge
Enumerates the slide-in and slide-out positions of the component from the screen edge during transition.
ArkUI_TranslationOptions
Defines the translation options for component transition.
ArkUI_UIStateapi-20
Defines the navigation point indicator style of the component. Enumerates the UI states of a component, used for handling state-specific styles.
ArkUI_VerticalAlignment
Enumerates the vertical alignment modes.
ArkUI_Visibility
Enumerates the visibility values.
ArkUI_VisibleAreaEventOptionsapi-17
Defines the parameters for visible area change events.
ArkUI_WaterFlowLayoutModeapi-18
Enumerates the layout modes of the WaterFlow component.
ArkUI_WaterFlowSectionOption
Defines the water flow section configuration.
ArkUI_WordBreak
Enumerates the word break rules.
ArkUI_XComponentType
Enumerates the types of the component.
ArkUiErrorCode
Define error code enumeration values.

Functions

OH_ArkUI_AccessibilityState_Create
Create accessibility state.
OH_ArkUI_AccessibilityState_Dispose
Dispose accessibility state.
OH_ArkUI_AccessibilityState_GetCheckedState
Get accessibility checked state.
OH_ArkUI_AccessibilityState_IsDisabled
Get accessibility state disabled.
OH_ArkUI_AccessibilityState_IsSelected
Get accessibility state selected.
OH_ArkUI_AccessibilityState_SetCheckedState
Set accessibility checked state.
OH_ArkUI_AccessibilityState_SetDisabled
Set accessibility state disabled.
OH_ArkUI_AccessibilityState_SetSelected
Set accessibility state selected.
OH_ArkUI_AccessibilityValue_Create
Create accessibility value.
OH_ArkUI_AccessibilityValue_Dispose
Dispose accessibility value.
OH_ArkUI_AccessibilityValue_GetCurrent
Get accessibility current value.
OH_ArkUI_AccessibilityValue_GetMax
Get accessibility minimum value.
OH_ArkUI_AccessibilityValue_GetMin
Get accessibility minimum value.
OH_ArkUI_AccessibilityValue_GetRangeCurrentapi-18
Get accessibility current value.
OH_ArkUI_AccessibilityValue_GetRangeMaxapi-18
Get accessibility maximum value.
OH_ArkUI_AccessibilityValue_GetRangeMinapi-18
Get accessibility minimum value.
OH_ArkUI_AccessibilityValue_GetText
Get accessibility text value.
OH_ArkUI_AccessibilityValue_SetCurrent
Set accessibility current value.
OH_ArkUI_AccessibilityValue_SetMax
Set accessibility minimum value.
OH_ArkUI_AccessibilityValue_SetMin
Set accessibility minimum value.
OH_ArkUI_AccessibilityValue_SetRangeCurrentapi-18
Set accessibility current value.
OH_ArkUI_AccessibilityValue_SetRangeMaxapi-18
Set accessibility maximum value.
OH_ArkUI_AccessibilityValue_SetRangeMinapi-18
Set accessibility minimum value.
OH_ArkUI_AccessibilityValue_SetText
Set accessibility text value.
OH_ArkUI_ActiveChildrenInfo_Destroyapi-14
Destroy ActiveChildenInfo instance.
OH_ArkUI_ActiveChildrenInfo_GetCountapi-14
Retrieve the number of nodes within the structure of ActiveChildenInfo.
OH_ArkUI_ActiveChildrenInfo_GetNodeByIndexapi-14
Retrieve the child nodes of ActiveChildenInfo with the structure index.
OH_ArkUI_AlignmentRuleOption_Create
creates alignment rule information for subcomponents in relative containers.
OH_ArkUI_AlignmentRuleOption_Dispose
Destroys the alignment rule information of subcomponents in relative containers.
OH_ArkUI_AlignmentRuleOption_GetBiasHorizontal
Get the bias value in the horizontal direction.
OH_ArkUI_AlignmentRuleOption_GetBiasVertical
Get the bias value in the vertical direction.
OH_ArkUI_AlignmentRuleOption_GetBottomAlignment
Get the bottom alignment parameters.
OH_ArkUI_AlignmentRuleOption_GetBottomId
Get the bottom alignment parameters.
OH_ArkUI_AlignmentRuleOption_GetCenterAlignmentHorizontal
Gets the parameters of horizontal center alignment.
OH_ArkUI_AlignmentRuleOption_GetCenterAlignmentVertical
Gets the parameters of vertical center alignment.
OH_ArkUI_AlignmentRuleOption_GetCenterIdHorizontal
Gets the parameters of horizontal center alignment.
OH_ArkUI_AlignmentRuleOption_GetCenterIdVertical
Gets the parameters of vertical center alignment.
OH_ArkUI_AlignmentRuleOption_GetEndAlignment
Get the end alignment parameter.
OH_ArkUI_AlignmentRuleOption_GetEndId
Get the end alignment parameter.
OH_ArkUI_AlignmentRuleOption_GetStartAlignment
Gets the alignment of the start-aligned parameter.
OH_ArkUI_AlignmentRuleOption_GetStartId
Get the Id of the start-aligned parameter.
OH_ArkUI_AlignmentRuleOption_GetTopAlignment
Get the top-aligned parameters.
OH_ArkUI_AlignmentRuleOption_GetTopId
Get the top-aligned parameters.
OH_ArkUI_AlignmentRuleOption_SetBiasHorizontal
Sets the horizontal offset parameter of the component under the anchor point constraint.
OH_ArkUI_AlignmentRuleOption_SetBiasVertical
Set the vertical offset parameter of the component under the anchor point constraint.
OH_ArkUI_AlignmentRuleOption_SetBottom
Set the bottom alignment parameters.
OH_ArkUI_AlignmentRuleOption_SetCenterHorizontal
Set the parameters for horizontal center alignment.
OH_ArkUI_AlignmentRuleOption_SetCenterVertical
Set the parameters for vertical center alignment.
OH_ArkUI_AlignmentRuleOption_SetEnd
Set the end alignment parameter.
OH_ArkUI_AlignmentRuleOption_SetStart
Set the start alignment parameter.
OH_ArkUI_AlignmentRuleOption_SetTop
Set the parameters for top alignment.
OH_ArkUI_BarrierOption_Create
creates barrier information within the RelativeContaine container.
OH_ArkUI_BarrierOption_Dispose
Destroy barrier information.
OH_ArkUI_BarrierOption_GetDirection
Gets the direction of the barrier.
OH_ArkUI_BarrierOption_GetId
Get the Id of the barrier.
OH_ArkUI_BarrierOption_GetReferencedId
Get the dependent components of the barrier.
OH_ArkUI_BarrierOption_GetReferencedIdSize
Gets the number of dependent components of the barrier.
OH_ArkUI_BarrierOption_SetDirection
Set the direction of the barrier.
OH_ArkUI_BarrierOption_SetId
Set the Id of the barrier.
OH_ArkUI_BarrierOption_SetReferencedId
Sets the dependent component of the barrier.
OH_ArkUI_ContentTransitionEffect_Createapi-21
creates content switching animation effects.
OH_ArkUI_CreateSnapshotOptionsapi-15
Creates an option for taking snapshot, the returned value must be released through OH_ArkUI_DestroySnapshotOptions when it’s not used anymore.
OH_ArkUI_CrossLanguageOption_Createapi-15
Create a cross-language option instance.
OH_ArkUI_CrossLanguageOption_Destroyapi-15
Destroy the cross-language option instance.
OH_ArkUI_CrossLanguageOption_GetAttributeSettingStatusapi-15
Get the attribute setting enable of the cross-language option.
OH_ArkUI_CrossLanguageOption_SetAttributeSettingStatusapi-15
Enable the attribute setting in the cross-language option.
OH_ArkUI_CustomProperty_Destroyapi-14
Destroy the instance of Customs Property.
OH_ArkUI_CustomProperty_GetStringValueapi-14
Get custom attribute value information.
OH_ArkUI_CustomSpanDrawInfo_Create
Creates drawing information for this custom span.
OH_ArkUI_CustomSpanDrawInfo_Dispose
Disposes of drawing information for this custom span.
OH_ArkUI_CustomSpanDrawInfo_GetBaseline
Obtains the baseline offset of the custom span relative to the mounted component.
OH_ArkUI_CustomSpanDrawInfo_GetLineBottom
Obtains the bottom margin of the custom span relative to the mounted component.
OH_ArkUI_CustomSpanDrawInfo_GetLineTop
Obtains the top margin of the custom span relative to the mounted component.
OH_ArkUI_CustomSpanDrawInfo_GetXOffset
Obtains the x-axis offset of the custom span relative to the mounted component.
OH_ArkUI_CustomSpanMeasureInfo_Create
Creates measurement information for this custom span.
OH_ArkUI_CustomSpanMeasureInfo_Dispose
Disposes of measurement information of this custom span.
OH_ArkUI_CustomSpanMeasureInfo_GetFontSize
Obtains the font size of a custom span.
OH_ArkUI_CustomSpanMetrics_Create
Creates measurement metrics for this custom span.
OH_ArkUI_CustomSpanMetrics_Dispose
Disposes of measurement metrics of this custom span.
OH_ArkUI_CustomSpanMetrics_SetHeight
Sets the height for a custom span.
OH_ArkUI_CustomSpanMetrics_SetWidth
Sets the width for a custom span.
OH_ArkUI_DestroySnapshotOptionsapi-15
Dispose a snapshot option object.
OH_ArkUI_DrawContext_GetCanvas
Obtains the pointer to a canvas for drawing, which can be converted into the OH_Drawing_Canvas pointer in the Drawing module.
OH_ArkUI_DrawContext_GetSize
Obtains the size of a drawing area.
OH_ArkUI_EmbeddedComponentOption_Createapi-20
Create an object for the EmbeddedComponent option.
OH_ArkUI_EmbeddedComponentOption_Disposeapi-20
Destroy the object by EmbeddedComponent option.
OH_ArkUI_EmbeddedComponentOption_SetOnErrorapi-20
Set the onError of EmbeddedComponent.
OH_ArkUI_EmbeddedComponentOption_SetOnTerminatedapi-20
Set the onTerminated of EmbeddedComponent.
OH_ArkUI_GridLayoutOptions_Createapi-22
Creates Grid layout options.
OH_ArkUI_GridLayoutOptions_Disposeapi-22
Disposes of Grid layout options.
OH_ArkUI_GridLayoutOptions_GetIrregularIndexesapi-22
Obtains the irregular grid item index array for the grid layout. When OH_ArkUI_GridLayoutOptions_RegisterGetIrregularSizeByIndexCallback is not set, the grid item specified in irregularIndexes occupies an entire row of the grid that scrolls vertically or an entire column of the grid that scrolls horizontally.
OH_ArkUI_GridLayoutOptions_RegisterGetIrregularSizeByIndexCallbackapi-22
Registers a callback to obtain the row and column span for the grid item at the specified index.
OH_ArkUI_GridLayoutOptions_RegisterGetRectByIndexCallbackapi-22
Registers a callback to obtain the starting row, starting column, row span, and column span for the grid item at the specified index.
OH_ArkUI_GridLayoutOptions_SetIrregularIndexesapi-22
Sets the irregular grid item index array for the grid layout.
OH_ArkUI_GuidelineOption_Create
Create auxiliary line information in the RelativeContaine container.
OH_ArkUI_GuidelineOption_Dispose
Destroy auxiliary line information.
OH_ArkUI_GuidelineOption_GetDirection
Get the direction of the auxiliary line.
OH_ArkUI_GuidelineOption_GetId
Get the Id of the auxiliary line.
OH_ArkUI_GuidelineOption_GetPositionEnd
Get the distance from the right side or bottom of the container.
OH_ArkUI_GuidelineOption_GetPositionStart
Get the distance from the left or top of the container.
OH_ArkUI_GuidelineOption_SetDirection
Set the direction of the auxiliary line.
OH_ArkUI_GuidelineOption_SetId
Set the Id of the auxiliary line.
OH_ArkUI_GuidelineOption_SetPositionEnd
Set the distance from the right or bottom of the container.
OH_ArkUI_GuidelineOption_SetPositionStart
Set the distance from the left or top of the container.
OH_ArkUI_HostWindowInfo_Destroyapi-15
Destroy the instance of HostWindowInfo.
OH_ArkUI_HostWindowInfo_GetNameapi-15
Get window name from HostWindowInfo.
OH_ArkUI_ImageAnimatorFrameInfo_CreateFromDrawableDescriptor
Create a image frame from the drawable descriptor.
OH_ArkUI_ImageAnimatorFrameInfo_CreateFromString
Create a image frame from the image path.
OH_ArkUI_ImageAnimatorFrameInfo_Dispose
Destroy the pointer to the image frame.
OH_ArkUI_ImageAnimatorFrameInfo_GetDuration
Get the playback duration of the image frame.
OH_ArkUI_ImageAnimatorFrameInfo_GetHeight
Get the height of the image frame.
OH_ArkUI_ImageAnimatorFrameInfo_GetLeft
Get the horizontal coordinate of the image relative to the upper left corner of the widget.
OH_ArkUI_ImageAnimatorFrameInfo_GetTop
Get the vertical coordinate of the image relative to the upper left corner of the widget.
OH_ArkUI_ImageAnimatorFrameInfo_GetWidth
Get the width of the image frame.
OH_ArkUI_ImageAnimatorFrameInfo_SetDuration
Set the playback duration of the image frame.
OH_ArkUI_ImageAnimatorFrameInfo_SetHeight
Set the height of the image frame.
OH_ArkUI_ImageAnimatorFrameInfo_SetLeft
Set the horizontal coordinate of the image relative to the upper left corner of the widget.
OH_ArkUI_ImageAnimatorFrameInfo_SetTop
Set the vertical coordinate of the image relative to the upper left corner of the widget.
OH_ArkUI_ImageAnimatorFrameInfo_SetWidth
Set the width of the image frame.
OH_ArkUI_LayoutConstraint_Copy
Creates a deep copy of a size constraint.
OH_ArkUI_LayoutConstraint_Create
Creates a size constraint.
OH_ArkUI_LayoutConstraint_Dispose
Destroys the pointer to a size constraint.
OH_ArkUI_LayoutConstraint_GetMaxHeight
Obtains the maximum height for a size constraint, in px.
OH_ArkUI_LayoutConstraint_GetMaxWidth
Obtains the maximum width for a size constraint, in px.
OH_ArkUI_LayoutConstraint_GetMinHeight
Obtains the minimum height for a size constraint, in px.
OH_ArkUI_LayoutConstraint_GetMinWidth
Obtains the minimum width for a size constraint, in px.
OH_ArkUI_LayoutConstraint_GetPercentReferenceHeight
Obtains the height percentage reference for a size constraint, in px.
OH_ArkUI_LayoutConstraint_GetPercentReferenceWidth
Obtains the width percentage reference for a size constraint, in px.
OH_ArkUI_LayoutConstraint_SetMaxHeight
Sets the maximum height.
OH_ArkUI_LayoutConstraint_SetMaxWidth
Sets the maximum width.
OH_ArkUI_LayoutConstraint_SetMinHeight
Sets the minimum height.
OH_ArkUI_LayoutConstraint_SetMinWidth
Sets the minimum width.
OH_ArkUI_LayoutConstraint_SetPercentReferenceHeight
Sets the height percentage reference.
OH_ArkUI_LayoutConstraint_SetPercentReferenceWidth
Sets the width percentage reference.
OH_ArkUI_ListChildrenMainSizeOption_Create
Create configuration items for the ListChildrenMainSize interface settings.
OH_ArkUI_ListChildrenMainSizeOption_Dispose
Destroy the ListChildrenMainSize instance.
OH_ArkUI_ListChildrenMainSizeOption_GetDefaultMainSize
Get the default size of ChildrenMainSizeOption for the List component.
OH_ArkUI_ListChildrenMainSizeOption_GetMainSize
Get the value of the ChildrenMainSizeOption array for the List component.
OH_ArkUI_ListChildrenMainSizeOption_Resize
Reset the array size of ChildrenMainSizeOption for the List component.
OH_ArkUI_ListChildrenMainSizeOption_SetDefaultMainSize
Set the default size of ChildrenMainSizeOption for the List component.
OH_ArkUI_ListChildrenMainSizeOption_Splice
Resize the ChildrenMainSizeOption array operation on the List component.
OH_ArkUI_ListChildrenMainSizeOption_UpdateSize
Update the value of the ChildrenMainSizeOption array in the List component.
OH_ArkUI_ListItemSwipeActionItem_Create
Create a configuration item for the ListitemSwipeActionItem interface settings.
OH_ArkUI_ListItemSwipeActionItem_Dispose
Destroy the ListitemSwipeActionItem instance.
OH_ArkUI_ListItemSwipeActionItem_GetActionAreaDistance
Obtain the threshold for long-distance sliding deletion distance of components.
OH_ArkUI_ListItemSwipeActionItem_SetActionAreaDistance
Set the threshold for long-distance sliding deletion distance of components.
OH_ArkUI_ListItemSwipeActionItem_SetContent
Set the layout content of ListItem SwipeActionItem.
OH_ArkUI_ListItemSwipeActionItem_SetOnAction
Set the event to be called when a component enters the long-range deletion area and deletes a ListItem.
OH_ArkUI_ListItemSwipeActionItem_SetOnActionWithUserData
Set the event triggered when a component enters the long-range deletion area and deletes a ListItem.
OH_ArkUI_ListItemSwipeActionItem_SetOnEnterActionArea
Set the event to be called when a sliding entry enters the deletion area.
OH_ArkUI_ListItemSwipeActionItem_SetOnEnterActionAreaWithUserData
Set the event triggered when a sliding entry enters the deletion area.
OH_ArkUI_ListItemSwipeActionItem_SetOnExitActionArea
Set the event to be called when a sliding entry exits the deletion area.
OH_ArkUI_ListItemSwipeActionItem_SetOnExitActionAreaWithUserData
Set the event triggered when a sliding entry exits the deletion area.
OH_ArkUI_ListItemSwipeActionItem_SetOnStateChange
Set the event triggered when the sliding state of a list item changes.
OH_ArkUI_ListItemSwipeActionItem_SetOnStateChangeWithUserData
Set the event triggered when the sliding state of a list item changes.
OH_ArkUI_ListItemSwipeActionOption_Create
Create a configuration item for the ListitemSwipeActionOption interface settings.
OH_ArkUI_ListItemSwipeActionOption_Dispose
Destroy the ListitemSwipeActionOption instance.
OH_ArkUI_ListItemSwipeActionOption_GetEdgeEffect
Get the sliding effect.
OH_ArkUI_ListItemSwipeActionOption_SetEdgeEffect
Set the sliding effect.
OH_ArkUI_ListItemSwipeActionOption_SetEnd
Set the layout content on the right (vertical layout) or bottom (horizontal layout) of the ListItem SwipeActionItem.
OH_ArkUI_ListItemSwipeActionOption_SetOnOffsetChange
The event called when the sliding operation offset changes.
OH_ArkUI_ListItemSwipeActionOption_SetOnOffsetChangeWithUserData
Set the event triggered when the sliding operation offset changes.
OH_ArkUI_ListItemSwipeActionOption_SetStart
Set the layout content on the left (vertical layout) or top (horizontal layout) of the ListItem SwipeActionItem.
OH_ArkUI_ListItemSwipeAction_Collapseapi-21
Collapse the swipe action.
OH_ArkUI_ListItemSwipeAction_Expandapi-21
Expand the swipe action.
OH_ArkUI_MotionPathOptions_Createapi-23
Create an object of the motion path options for path animation. In the newly created ArkUI_MotionPathOptions, the “path” value is an empty string, the “from” value is 0, the “to” value is 1, and the “rotatable” value is false.
OH_ArkUI_MotionPathOptions_Disposeapi-23
Dispose the ArkUI_MotionPathOptions object.
OH_ArkUI_MotionPathOptions_GetFromapi-23
Gets the starting progress in the ArkUI_MotionPathOptions object.
OH_ArkUI_MotionPathOptions_GetPathapi-23
Gets the motion path string in the ArkUI_MotionPathOptions object.
OH_ArkUI_MotionPathOptions_GetRotatableapi-23
Gets the rotatable parameter in the ArkUI_MotionPathOptions.
OH_ArkUI_MotionPathOptions_GetToapi-23
Gets the endpoint progress in the ArkUI_MotionPathOptions object.
OH_ArkUI_MotionPathOptions_SetFromapi-23
Sets the starting progress in the ArkUI_MotionPathOptions. Progress refers to the ratio of the length of the path that has been traveled to the total length of the entire path. The value range is [0.0, 1.0], and the “from” value should be less than or equal to the “to” value; otherwise, an ARKUI_ERROR_CODE_PARAM_OUT_OF_RANGE error code will be returned.
OH_ArkUI_MotionPathOptions_SetPathapi-23
Sets the the motion path for the animation using an SVG path string. The path supports using “start” and “end” as placeholders for the starting and ending points, for example: “Mstart.x start.y L50 50 Lend.x end.y Z”. Refer to the SVG path format for the path string. When set to an empty string, it is equivalent to not setting a path animation.
OH_ArkUI_MotionPathOptions_SetRotatableapi-23
Sets the rotatable parameter in the ArkUI_MotionPathOptions. It indicates whether to rotate along the path. True means rotating along the path, while false means not rotating along the path.
OH_ArkUI_MotionPathOptions_SetToapi-23
Sets the endpoint progress in the ArkUI_MotionPathOptions. Progress refers to the ratio of the length of the path that has been traveled to the total length of the entire path. The value range is [0.0, 1.0], and the “from” value should be less than or equal to the “to” value; otherwise, an ARKUI_ERROR_CODE_PARAM_OUT_OF_RANGE error code will be returned.
OH_ArkUI_PickerIndicatorStyle_ConfigureBackgroundapi-23
Set the parameters of background style.
OH_ArkUI_PickerIndicatorStyle_ConfigureDividerapi-23
Set the parameters of divider style.
OH_ArkUI_PickerIndicatorStyle_Createapi-23
Create the ArkUI_PickerIndicatorStyle instance.
OH_ArkUI_PickerIndicatorStyle_Disposeapi-23
Destroy the ArkUI_PickerIndicatorStyle instance.
OH_ArkUI_PixelRoundPolicy_Createapi-21
Create a policy object for PixelRound attribute.
OH_ArkUI_PixelRoundPolicy_Disposeapi-21
Dispose a policy object for PixelRound attribute.
OH_ArkUI_PixelRoundPolicy_GetBottomapi-21
Gets the bottom edge of a policy object for PixelRound attribute.
OH_ArkUI_PixelRoundPolicy_GetEndapi-21
Gets the end edge of a policy object for PixelRound attribute.
OH_ArkUI_PixelRoundPolicy_GetStartapi-21
Gets the start edge of a policy object for PixelRound attribute.
OH_ArkUI_PixelRoundPolicy_GetTopapi-21
Gets the top edge of a policy object for PixelRound attribute.
OH_ArkUI_PixelRoundPolicy_SetBottomapi-21
Sets the bottom edge of a policy object for PixelRound attribute.
OH_ArkUI_PixelRoundPolicy_SetEndapi-21
Sets the end edge of a policy object for PixelRound attribute.
OH_ArkUI_PixelRoundPolicy_SetStartapi-21
Sets the start edge of a policy object for PixelRound attribute.
OH_ArkUI_PixelRoundPolicy_SetTopapi-21
Sets the top edge of a policy object for PixelRound attribute.
OH_ArkUI_PositionEdges_Copyapi-21
Creates a deep copy of an edge object for position attribute.
OH_ArkUI_PositionEdges_Createapi-21
Create an edge object for position attribute.
OH_ArkUI_PositionEdges_Disposeapi-21
Dispose an edge object for position attribute.
OH_ArkUI_PositionEdges_GetBottomapi-21
Gets the bottom edge of an edge object for position attribute.
OH_ArkUI_PositionEdges_GetLeftapi-21
Gets the left edge of an edge object for position attribute.
OH_ArkUI_PositionEdges_GetRightapi-21
Gets the right edge of an edge object for position attribute.
OH_ArkUI_PositionEdges_GetTopapi-21
Gets the top edge of an edge object for position attribute.
OH_ArkUI_PositionEdges_SetBottomapi-21
Sets the bottom edge of an edge object for position attribute.
OH_ArkUI_PositionEdges_SetLeftapi-21
Sets the left edge of an edge object for position attribute.
OH_ArkUI_PositionEdges_SetRightapi-21
Sets the right edge of an edge object for position attribute.
OH_ArkUI_PositionEdges_SetTopapi-21
Sets the top edge of an edge object for position attribute.
OH_ArkUI_ProgressLinearStyleOption_Createapi-15
Create linear progress indicator style information.
OH_ArkUI_ProgressLinearStyleOption_Destroyapi-15
Destroy linear progress indicator style information.
OH_ArkUI_ProgressLinearStyleOption_GetScanEffectEnabledapi-15
Get whether scan effect is enable.
OH_ArkUI_ProgressLinearStyleOption_GetSmoothEffectEnabledapi-15
Get whether smoothing effect is enabled.
OH_ArkUI_ProgressLinearStyleOption_GetStrokeRadiusapi-15
Get linear progress indicator stroke radius.
OH_ArkUI_ProgressLinearStyleOption_GetStrokeWidthapi-15
Get linear progress indicator stroke width.
OH_ArkUI_ProgressLinearStyleOption_SetScanEffectEnabledapi-15
Set whether the scan effect is enabled.
OH_ArkUI_ProgressLinearStyleOption_SetSmoothEffectEnabledapi-15
Set whether smoothing effect is enabled.
OH_ArkUI_ProgressLinearStyleOption_SetStrokeRadiusapi-15
Set linear progress indicator stroke radius.
OH_ArkUI_ProgressLinearStyleOption_SetStrokeWidthapi-15
Set linear progress indicator stroke width.
OH_ArkUI_SelectedDragPreviewStyle_Createapi-23
Create a configuration object for selected drag preview style.
OH_ArkUI_SelectedDragPreviewStyle_Disposeapi-23
Dispose a configuration object for selected drag preview style.
OH_ArkUI_SelectedDragPreviewStyle_GetColorapi-23
Gets the color of background for selected drag preview style.
OH_ArkUI_SelectedDragPreviewStyle_SetColorapi-23
Sets the color of background for selected drag preview style.
OH_ArkUI_SelectionOptions_Createapi-23
Create selection options.
OH_ArkUI_SelectionOptions_Disposeapi-23
Dispose selection options object.
OH_ArkUI_SelectionOptions_GetMenuPolicyapi-23
Gets the menu policy of selection options.
OH_ArkUI_SelectionOptions_SetMenuPolicyapi-23
Sets the menu policy for selection options.
OH_ArkUI_ShowCounterConfig_Createapi-22
Creates a configuration object for textField’s counter.
OH_ArkUI_ShowCounterConfig_Disposeapi-22
Disposes a configuration object for textField’s counter.
OH_ArkUI_ShowCounterConfig_GetCounterTextColorapi-22
Gets the color of counter when textField hasn’t wanted to exceed the maximum character count.
OH_ArkUI_ShowCounterConfig_GetCounterTextOverflowColorapi-22
Gets the color of counter when textField wants to exceed the maximum character count.
OH_ArkUI_ShowCounterConfig_SetCounterTextColorapi-22
Sets the color of counter when textField hasn’t wanted to exceed the maximum character count.
OH_ArkUI_ShowCounterConfig_SetCounterTextOverflowColorapi-22
Sets the color of counter when textField wants to exceed the maximum character count.
OH_ArkUI_SnapshotOptions_SetColorModeapi-23
Sets the color mode for snapshot capture. By default, snapshots are captured in SRGB mode, which may lose visual effects for components using wide color gamut display modes. If the target component’s color space is known, specify it through colorSpace and set isAuto to false to achieve optimal snapshot quality. Since determining the exact color space used by a component is often difficult, set isAuto to true to let the system automatically select the appropriate color space. If isAuto is set to true, the colorSpace parameter value is ignored.
OH_ArkUI_SnapshotOptions_SetDynamicRangeModeapi-23
Sets the dynamic range mode for snapshot capture. By default, the system captures snapshots in [ARKUI_DYNAMIC_RANGE_MODE_STANDARD] mode. To use a specific mode, specify it via the dynamicRangeMode parameter and set isAuto to false. Alternatively, set isAuto to true to let the system auto-detect the appropriate dynamic range mode. If isAuto is set to true, the dynamicRangeMode parameter value is ignored.
OH_ArkUI_SnapshotOptions_SetScaleapi-15
Config the snapshot option with scale.
OH_ArkUI_SwiperArrowStyle_Createapi-19
Creates a arrow style for swiper.
OH_ArkUI_SwiperArrowStyle_Destroyapi-19
Destroys the arrow style.
OH_ArkUI_SwiperArrowStyle_GetArrowColorapi-19
Gets the color of the arrow.
OH_ArkUI_SwiperArrowStyle_GetArrowSizeapi-19
Gets the size of the arrow.
OH_ArkUI_SwiperArrowStyle_GetBackgroundColorapi-19
Gets the background color of the arrow.
OH_ArkUI_SwiperArrowStyle_GetBackgroundSizeapi-19
Gets the background size of the arrow.
OH_ArkUI_SwiperArrowStyle_GetShowBackgroundapi-19
Gets whether to show the background for the arrow.
OH_ArkUI_SwiperArrowStyle_GetShowSidebarMiddleapi-19
Gets the display position of the arrow.
OH_ArkUI_SwiperArrowStyle_SetArrowColorapi-19
Sets the color of the arrow.
OH_ArkUI_SwiperArrowStyle_SetArrowSizeapi-19
Sets the size of the arrow.
OH_ArkUI_SwiperArrowStyle_SetBackgroundColorapi-19
Sets the background color of the arrow.
OH_ArkUI_SwiperArrowStyle_SetBackgroundSizeapi-19
Sets the background size of the arrow.
OH_ArkUI_SwiperArrowStyle_SetShowBackgroundapi-19
Sets whether to show the background for the arrow.
OH_ArkUI_SwiperArrowStyle_SetShowSidebarMiddleapi-19
Sets the display position of the arrow.
OH_ArkUI_SwiperDigitIndicator_Createapi-19
Creates a digital indicator.
OH_ArkUI_SwiperDigitIndicator_Destroyapi-19
Destroys the digital indicator.
OH_ArkUI_SwiperDigitIndicator_GetBottomPositionapi-19
Gets the distance between the digital indicator and the bottom of the swiper.
OH_ArkUI_SwiperDigitIndicator_GetEndPositionapi-19
Gets the distance between the digital indicator and the end of the swiper.
OH_ArkUI_SwiperDigitIndicator_GetFontColorapi-19
Gets the font color of total count in the digital indicator.
OH_ArkUI_SwiperDigitIndicator_GetFontSizeapi-19
Gets the font size of total count in the digital indicator.
OH_ArkUI_SwiperDigitIndicator_GetFontWeightapi-19
Gets the font weight of total count in the digital indicator.
OH_ArkUI_SwiperDigitIndicator_GetIgnoreSizeOfBottomapi-19
Obtains whether to ignore the size of the indicator for OH_ArkUI_SwiperDigitIndicator_SetBottomPosition.
OH_ArkUI_SwiperDigitIndicator_GetSelectedFontColorapi-19
Gets the font color of selected index in the digital indicator.
OH_ArkUI_SwiperDigitIndicator_GetSelectedFontSizeapi-19
Gets the font size of selected index in the digital indicator.
OH_ArkUI_SwiperDigitIndicator_GetSelectedFontWeightapi-19
Gets the font weight of selected index in the digital indicator.
OH_ArkUI_SwiperDigitIndicator_GetStartPositionapi-19
Gets the distance between the digital indicator and the start of the swiper.
OH_ArkUI_SwiperDigitIndicator_GetTopPositionapi-19
Gets the distance between the digital indicator and the top of the swiper.
OH_ArkUI_SwiperDigitIndicator_SetBottomPositionapi-19
Sets the distance between the digital indicator and the bottom of the swiper.
OH_ArkUI_SwiperDigitIndicator_SetEndPositionapi-19
Sets the distance between the digital indicator and the end of the swiper.
OH_ArkUI_SwiperDigitIndicator_SetFontColorapi-19
Sets the font color of total count in the digital indicator.
OH_ArkUI_SwiperDigitIndicator_SetFontSizeapi-19
Sets the font size of total count in the digital indicator.
OH_ArkUI_SwiperDigitIndicator_SetFontWeightapi-19
Sets the font weight of total count in the digital indicator.
OH_ArkUI_SwiperDigitIndicator_SetIgnoreSizeOfBottomapi-19
Sets whether to ignore the size of the indicator for OH_ArkUI_SwiperDigitIndicator_SetBottomPosition.
OH_ArkUI_SwiperDigitIndicator_SetSelectedFontColorapi-19
Sets the font color of selected index in the digital indicator.
OH_ArkUI_SwiperDigitIndicator_SetSelectedFontSizeapi-19
Sets the font size of selected index in the digital indicator.
OH_ArkUI_SwiperDigitIndicator_SetSelectedFontWeightapi-19
Sets the font weight of selected index in the digital indicator.
OH_ArkUI_SwiperDigitIndicator_SetStartPositionapi-19
Sets the distance between the digital indicator and the start of the swiper.
OH_ArkUI_SwiperDigitIndicator_SetTopPositionapi-19
Sets the distance between the digital indicator and the top of the swiper.
OH_ArkUI_SwiperIndicator_Create
Creates a navigation indicator.
OH_ArkUI_SwiperIndicator_Dispose
Destroys the pointer to the indicator.
OH_ArkUI_SwiperIndicator_GetBottomPosition
Obtains the distance between the navigation point and the bottom of the swiper.
OH_ArkUI_SwiperIndicator_GetColor
Obtains the color of the dot navigation indicator.
OH_ArkUI_SwiperIndicator_GetEndPosition
Obtains the distance between the navigation point and the end of the swiper.
OH_ArkUI_SwiperIndicator_GetIgnoreSizeOfBottomapi-19
Obtains whether to ignore the size of the indicator for OH_ArkUI_SwiperIndicator_SetBottomPosition.
OH_ArkUI_SwiperIndicator_GetItemHeight
Obtains the height of the dot for the dot indicator.
OH_ArkUI_SwiperIndicator_GetItemWidth
Obtains the width of the dot for the dot indicator.
OH_ArkUI_SwiperIndicator_GetMask
Obtains whether to display the mask style of the dot navigation indicator.
OH_ArkUI_SwiperIndicator_GetMaxDisplayCount
Obtains the number of maxDisplayCount for the dot navigation indicator.
OH_ArkUI_SwiperIndicator_GetSelectedColor
Obtains the color of the selected dot for the dot navigation indicator.
OH_ArkUI_SwiperIndicator_GetSelectedItemHeight
Obtains the height of the selected dot for the dot indicator.
OH_ArkUI_SwiperIndicator_GetSelectedItemWidth
Obtains the width of the selected dot for the dot indicator.
OH_ArkUI_SwiperIndicator_GetSpaceapi-19
Obtains the space between the dots of the navigation indicator.
OH_ArkUI_SwiperIndicator_GetStartPosition
Obtains the distance between the navigation point and the start of the swiper.
OH_ArkUI_SwiperIndicator_GetTopPosition
Obtains the distance between the navigation point and the top of the swiper.
OH_ArkUI_SwiperIndicator_SetBottomPosition
Sets the distance between the navigation point and the bottom of the swiper.
OH_ArkUI_SwiperIndicator_SetColor
Sets the color of the dot navigation indicator.
OH_ArkUI_SwiperIndicator_SetEndPosition
Sets the distance between the navigation point and the right of the swiper.
OH_ArkUI_SwiperIndicator_SetIgnoreSizeOfBottomapi-19
Sets whether to ignore the size of the indicator for OH_ArkUI_SwiperIndicator_SetBottomPosition.
OH_ArkUI_SwiperIndicator_SetItemHeight
Sets the height of the dot for the dot indicator.
OH_ArkUI_SwiperIndicator_SetItemWidth
Sets the width of the dot for the dot indicator.
OH_ArkUI_SwiperIndicator_SetMask
Sets whether to display the mask style of the dot navigation indicator.
OH_ArkUI_SwiperIndicator_SetMaxDisplayCount
Sets the number of maxDisplayCount for the dot navigation indicator.
OH_ArkUI_SwiperIndicator_SetSelectedColor
Sets the color of the selected dot for the navigation indicator.
OH_ArkUI_SwiperIndicator_SetSelectedItemHeight
Sets the height of the selected dot for the dot indicator.
OH_ArkUI_SwiperIndicator_SetSelectedItemWidth
Sets the width of the selected dot for the dot indicator.
OH_ArkUI_SwiperIndicator_SetSpaceapi-19
Sets the space between the dots of the navigation indicator.
OH_ArkUI_SwiperIndicator_SetStartPosition
Sets the distance between the navigation point and the start of the swiper.
OH_ArkUI_SwiperIndicator_SetTopPosition
Sets the distance between the navigation point and the top of the swiper.
OH_ArkUI_TextCascadePickerRangeContentArray_Createapi-19
Creates a TextCascadePickerRangeContent instance.
OH_ArkUI_TextCascadePickerRangeContentArray_Destroyapi-19
Destroy the TextCascadePickerRangeContent instance.
OH_ArkUI_TextCascadePickerRangeContentArray_SetChildAtIndexapi-19
Sets the childs info of items in a multi text picker ranges.
OH_ArkUI_TextCascadePickerRangeContentArray_SetTextAtIndexapi-19
Sets the text of items in a multi text picker ranges.
OH_ArkUI_TextContentBaseController_Createapi-23
Create an object of the text content base controller.
OH_ArkUI_TextContentBaseController_DeleteBackwardapi-23
Delete the character before the caret of the input field component in editing state. Otherwise, delete the last character of the input field component.
OH_ArkUI_TextContentBaseController_Disposeapi-23
Dispose an object of the text content base controller.
OH_ArkUI_TextContentBaseController_ScrollToVisibleapi-23
Scroll the input field component to make the specified content visible.
OH_ArkUI_TextEditMenuOptions_Createapi-22
Create an object of the text edit menu options.
OH_ArkUI_TextEditMenuOptions_Disposeapi-22
Dispose an object of the text edit menu options.
OH_ArkUI_TextEditMenuOptions_RegisterOnCreateMenuCallbackapi-22
Set the event to be called when text menu create.
OH_ArkUI_TextEditMenuOptions_RegisterOnMenuItemClickCallbackapi-22
Set the event to be called when menu item click.
OH_ArkUI_TextEditMenuOptions_RegisterOnPrepareMenuCallbackapi-22
Set the event to be called when menu prepare.
OH_ArkUI_TextMarqueeOptions_Createapi-23
Create an option object for marquee animation of text.
OH_ArkUI_TextMarqueeOptions_Disposeapi-23
Dispose the option object for marquee animation of text.
OH_ArkUI_TextMarqueeOptions_GetDelayapi-23
Gets the delay time between each round of the option object for marquee animation of text.
OH_ArkUI_TextMarqueeOptions_GetFadeoutapi-23
Gets the fadeout flag of the option object for marquee animation of text.
OH_ArkUI_TextMarqueeOptions_GetFromStartapi-23
Gets the fromStart flag of the option object for marquee animation of text.
OH_ArkUI_TextMarqueeOptions_GetLoopapi-23
Gets the rounds of the option object for marquee animation of text.
OH_ArkUI_TextMarqueeOptions_GetSpacingapi-23
Gets the spacing between two rounds of the option object for marquee animation of text.
OH_ArkUI_TextMarqueeOptions_GetStartapi-23
Gets the start flag of the option object for marquee animation of text.
OH_ArkUI_TextMarqueeOptions_GetStartPolicyapi-23
Gets the start policy of the option object for marquee animation of text.
OH_ArkUI_TextMarqueeOptions_GetStepapi-23
Gets the step size of the option object for marquee animation of text.
OH_ArkUI_TextMarqueeOptions_GetUpdatePolicyapi-23
Gets the update policy of the option object for marquee animation of text.
OH_ArkUI_TextMarqueeOptions_SetDelayapi-23
Sets the delay time between each round of the option object for marquee animation of text.
OH_ArkUI_TextMarqueeOptions_SetFadeoutapi-23
Sets the fadeout flag of the option object for marquee animation of text.
OH_ArkUI_TextMarqueeOptions_SetFromStartapi-23
Sets the fromStart flag of the option object for marquee animation of text.
OH_ArkUI_TextMarqueeOptions_SetLoopapi-23
Sets the rounds of the option object for marquee animation of text.
OH_ArkUI_TextMarqueeOptions_SetSpacingapi-23
Sets the spacing between two rounds of the option object for marquee animation of text.
OH_ArkUI_TextMarqueeOptions_SetStartapi-23
Sets the start flag of the option object for marquee animation of text.
OH_ArkUI_TextMarqueeOptions_SetStartPolicyapi-23
Sets the start policy of the option object for marquee animation of text.
OH_ArkUI_TextMarqueeOptions_SetStepapi-23
Sets the step size of the option object for marquee animation of text.
OH_ArkUI_TextMarqueeOptions_SetUpdatePolicyapi-23
Sets the update policy of the option object for marquee animation of text.
OH_ArkUI_TextMenuItemArray_Clearapi-22
Clear all the items.
OH_ArkUI_TextMenuItemArray_Eraseapi-22
Erase text menu item at index.
OH_ArkUI_TextMenuItemArray_GetItemapi-22
Get text menu item at index.
OH_ArkUI_TextMenuItemArray_GetSizeapi-22
Get the size of text menu items.
OH_ArkUI_TextMenuItemArray_Insertapi-22
Insert text menu item at index.
OH_ArkUI_TextMenuItem_Createapi-22
Create an object of the text edit menu item.
OH_ArkUI_TextMenuItem_Disposeapi-22
Dispose an object of the text edit menu options.
OH_ArkUI_TextMenuItem_GetContentapi-22
Get text menu item title.
OH_ArkUI_TextMenuItem_GetIconapi-22
Get text menu item icon.
OH_ArkUI_TextMenuItem_GetIdapi-22
Get text menu item id.
OH_ArkUI_TextMenuItem_GetLabelInfoapi-22
Get text menu item label info for keyboard shortcut..
OH_ArkUI_TextMenuItem_SetContentapi-22
Set text menu item title.
OH_ArkUI_TextMenuItem_SetIconapi-22
Set text menu item icon.
OH_ArkUI_TextMenuItem_SetIdapi-22
Set text menu item id.
OH_ArkUI_TextMenuItem_SetLabelInfoapi-22
Set text menu item label info for keyboard shortcut.
OH_ArkUI_TextPickerRangeContentArray_Createapi-19
Creates a TextPickerRangeContent instance.
OH_ArkUI_TextPickerRangeContentArray_Destroyapi-19
Destroy the TextPickerRangeContent instance.
OH_ArkUI_TextPickerRangeContentArray_SetIconAtIndexapi-19
Sets the icon of items in a text picker ranges.
OH_ArkUI_TextPickerRangeContentArray_SetTextAtIndexapi-19
Sets the text of items in a text picker ranges
OH_ArkUI_TextSelectionMenuOptions_Createapi-22
Create an object of the text selection menu options.
OH_ArkUI_TextSelectionMenuOptions_Disposeapi-22
Dispose an object of the text selection menu options.
OH_ArkUI_TextSelectionMenuOptions_GetContentNodeapi-22
Get custom text menu node of text.
OH_ArkUI_TextSelectionMenuOptions_GetResponseTypeapi-22
Gets the response type select menu options.
OH_ArkUI_TextSelectionMenuOptions_GetSpanTypeapi-22
Gets the span type select menu options.
OH_ArkUI_TextSelectionMenuOptions_RegisterOnMenuHideCallbackapi-22
Set the event to be called when selection menu hide.
OH_ArkUI_TextSelectionMenuOptions_RegisterOnMenuShowCallbackapi-22
Set the event to be called when selection menu show.
OH_ArkUI_TextSelectionMenuOptions_SetContentNodeapi-22
Set custom text menu node of text.
OH_ArkUI_TextSelectionMenuOptions_SetResponseTypeapi-22
Sets the recognition types of a configuration object for selected text recognition.
OH_ArkUI_TextSelectionMenuOptions_SetSpanTypeapi-22
Sets the recognition types of a configuration object for selected text recognition.
OH_ArkUI_VisibleAreaEventOptions_Createapi-17
Creates an instance of visible area change event parameters
OH_ArkUI_VisibleAreaEventOptions_Disposeapi-17
Disposes of an instance of visible area change event parameters.
OH_ArkUI_VisibleAreaEventOptions_GetExpectedUpdateIntervalapi-17
Obtains the expected update interval for visible area changes.
OH_ArkUI_VisibleAreaEventOptions_GetMeasureFromViewportapi-22
Obtains the value set through OH_ArkUI_VisibleAreaEventOptions_SetMeasureFromViewport .
OH_ArkUI_VisibleAreaEventOptions_GetRatiosapi-17
Obtains the threshold ratios for visible area changes.
OH_ArkUI_VisibleAreaEventOptions_SetExpectedUpdateIntervalapi-17
Sets the expected update interval for visible area changes.
OH_ArkUI_VisibleAreaEventOptions_SetMeasureFromViewportapi-22
Sets the flag for controlling if the child components can exceed the parent’s bounds. if set to false, the part that exceeds the parent’s bounds will be considered as invisible area, set to true to allow the exceeding, the part that exceeds will be considered as visible area.
OH_ArkUI_VisibleAreaEventOptions_SetRatiosapi-17
Sets the threshold ratios for visible area changes.
OH_ArkUI_WaterFlowSectionOption_Create
Creates water flow section configuration.
OH_ArkUI_WaterFlowSectionOption_Dispose
Destroys the pointer to a water flow section configuration.
OH_ArkUI_WaterFlowSectionOption_GetColumnGap
Obtains the gap between columns in the water flow section that matches the specified index.
OH_ArkUI_WaterFlowSectionOption_GetCrossCount
Obtains the number of columns (in a vertical layout) or rows (in a horizontal layout) in the water flow section that matches the specified index.
OH_ArkUI_WaterFlowSectionOption_GetItemCount
Obtains the number of items in the water flow section that matches the specified index.
OH_ArkUI_WaterFlowSectionOption_GetMargin
Obtains the margins of the water flow section that matches the specified index.
OH_ArkUI_WaterFlowSectionOption_GetRowGap
Obtains the gap between rows in the water flow section that matches the specified index.
OH_ArkUI_WaterFlowSectionOption_GetSize
Gets the FlowItem grouping configuration information array length.
OH_ArkUI_WaterFlowSectionOption_RegisterGetItemMainSizeCallbackByIndex
The FlowItem grouping configuration information getsthe spindle size of the specified Item based on flowItemIndex.
OH_ArkUI_WaterFlowSectionOption_RegisterGetItemMainSizeCallbackByIndexWithUserData
The FlowItem grouping configuration information getsthe spindle size of the specified Item based on flowItemIndex.
OH_ArkUI_WaterFlowSectionOption_SetColumnGap
Sets the gap between columns in the specified water flow section.
OH_ArkUI_WaterFlowSectionOption_SetCrossCount
Sets the number of columns (in a vertical layout) or rows (in a horizontal layout) of a water flow.
OH_ArkUI_WaterFlowSectionOption_SetItemCount
Sets the number of items in a water flow section.
OH_ArkUI_WaterFlowSectionOption_SetMargin
Sets the margins for the specified water flow section.
OH_ArkUI_WaterFlowSectionOption_SetRowGap
Sets the gap between rows in the specified water flow section.
OH_ArkUI_WaterFlowSectionOption_SetSize
Sets the FlowItem block configuration information array length.

Type Aliases

ArkUI_NativeDialogHandle
Defines the pointer to the custom dialog box controller of ArkUI on the native side.
ArkUI_NodeContentHandle
Defines the pointer type of the ArkUI node content
ArkUI_NodeHandle
ArkUI_TextCreateMenuCallbackapi-22
The text menu create callback function.
ArkUI_TextMenuItemClickCallbackapi-22
The text menu item click callback function.
ArkUI_TextPrepareMenuCallbackapi-22
The text menu prepare callback function.
ArkUiResult

Unions

ArkUI_NumberValue
Provides the number types of ArkUI in the native code.