#[repr(transparent)]pub struct ArkUI_GridItemAlignment(pub c_uint);Available on crate features
api-12 and api-22 only.Expand description
Enumerates the grid item alignment modes.
Available since API-level: 22
Tuple Fields
0: c_uintImplementations
Sourceimpl ArkUI_GridItemAlignment
impl ArkUI_GridItemAlignment
Sourcepub const GRID_ITEM_ALIGNMENT_DEFAULT: ArkUI_GridItemAlignment
pub const GRID_ITEM_ALIGNMENT_DEFAULT: ArkUI_GridItemAlignment
Use the default alignment mode of the grid.
Sourcepub const GRID_ITEM_ALIGNMENT_STRETCH: ArkUI_GridItemAlignment
pub const GRID_ITEM_ALIGNMENT_STRETCH: ArkUI_GridItemAlignment
Set the height of all grid items in a row to match the height of the tallest item in that row.