#[repr(transparent)]pub struct ArkUI_PixelRoundCalcPolicy(pub c_uint);Available on crate features
api-12 and api-21 only.Expand description
Enumerates the PixelRoundPolicy.
Available since API-level: 21
Tuple Fields
0: c_uintImplementations
Sourceimpl ArkUI_PixelRoundCalcPolicy
impl ArkUI_PixelRoundCalcPolicy
Sourcepub const ARKUI_PIXELROUNDCALCPOLICY_NOFORCEROUND: ArkUI_PixelRoundCalcPolicy
pub const ARKUI_PIXELROUNDCALCPOLICY_NOFORCEROUND: ArkUI_PixelRoundCalcPolicy
No Force round the component boundary coordinates to integer pixel.
Sourcepub const ARKUI_PIXELROUNDCALCPOLICY_FORCECEIL: ArkUI_PixelRoundCalcPolicy
pub const ARKUI_PIXELROUNDCALCPOLICY_FORCECEIL: ArkUI_PixelRoundCalcPolicy
Force ceil the component boundary coordinates to integer pixel.
Sourcepub const ARKUI_PIXELROUNDCALCPOLICY_FORCEFLOOR: ArkUI_PixelRoundCalcPolicy
pub const ARKUI_PIXELROUNDCALCPOLICY_FORCEFLOOR: ArkUI_PixelRoundCalcPolicy
Force floor the component boundary coordinates to integer pixel.