#[repr(transparent)]pub struct ArkUI_RenderStrategy(pub c_uint);Available on crate features
api-12 and api-23 only.Expand description
Enumerates the graphics rendering strategy.
Available since API-level: 23
Tuple Fields
0: c_uintImplementations
Sourceimpl ArkUI_RenderStrategy
impl ArkUI_RenderStrategy
Sourcepub const ARKUI_RENDERSTRATEGY_FAST: ArkUI_RenderStrategy
pub const ARKUI_RENDERSTRATEGY_FAST: ArkUI_RenderStrategy
The current component and its child components will be drawn directly onto the screen canvas.
Sourcepub const ARKUI_RENDERSTRATEGY_OFFSCREEN: ArkUI_RenderStrategy
pub const ARKUI_RENDERSTRATEGY_OFFSCREEN: ArkUI_RenderStrategy
The current component and its child components will first be drawn onto an off-screen canvas, then undergo some graphic rendering operations, and finally be drawn onto the main canvas.