ArkUI_TextMenuItemId

Struct ArkUI_TextMenuItemId 

#[repr(transparent)]
pub struct ArkUI_TextMenuItemId(pub c_uint);
Available on crate features api-12 and api-22 only.
Enumerates the text menu item id.

Available since API-level: 22

Tuple Fields

0: c_uint

Implementations

Source

impl ArkUI_TextMenuItemId

pub const ARKUI_TEXT_MENU_ITEM_ID_CUT: ArkUI_TextMenuItemId

Indicates the TextMenuItemId to copy and delete the currently selected text.

pub const ARKUI_TEXT_MENU_ITEM_ID_COPY: ArkUI_TextMenuItemId

Indicates the TextMenuItemId to copy the currently selected text to the clipboard.

pub const ARKUI_TEXT_MENU_ITEM_ID_PASTE: ArkUI_TextMenuItemId

Indicates the TextMenuItemId to copy the current contents of the clipboard into the text view.

pub const ARKUI_TEXT_MENU_ITEM_ID_SELECT_ALL: ArkUI_TextMenuItemId

Indicates the TextMenuItemId to select all text in a text view.

pub const ARKUI_TEXT_MENU_ITEM_ID_COLLABORATION_SERVICE: ArkUI_TextMenuItemId

Indicates the TextMenuItemId for collaboration service menu items.

pub const ARKUI_TEXT_MENU_ITEM_ID_CAMERA_INPUT: ArkUI_TextMenuItemId

Indicates the TextMenuItemId to recognize the text in the picture and input it into the text view.

pub const ARKUI_TEXT_MENU_ITEM_ID_AI_WRITER: ArkUI_TextMenuItemId

Indicates the TextMenuItemId to help with text creation by invoking large models.

pub const ARKUI_TEXT_MENU_ITEM_ID_TRANSLATE: ArkUI_TextMenuItemId

Indicates the TextMenuItemId to translate the selected content.

Indicates the TextMenuItemId to search the selected content.

pub const ARKUI_TEXT_MENU_ITEM_ID_SHARE: ArkUI_TextMenuItemId

Indicates the TextMenuItemId to share the selected content.

pub const ARKUI_TEXT_MENU_ITEM_ID_URL: ArkUI_TextMenuItemId

Indicates the TextMenuItemId to open url.

pub const ARKUI_TEXT_MENU_ITEM_ID_EMAIL: ArkUI_TextMenuItemId

Indicates the TextMenuItemId to open email.

pub const ARKUI_TEXT_MENU_ITEM_ID_PHONE_NUMBER: ArkUI_TextMenuItemId

Indicates the TextMenuItemId to call the phone number.

pub const ARKUI_TEXT_MENU_ITEM_ID_ADDRESS: ArkUI_TextMenuItemId

Indicates the TextMenuItemId to open map.

pub const ARKUI_TEXT_MENU_ITEM_ID_DATA_TIME: ArkUI_TextMenuItemId

Indicates the TextMenuItemId to open calendar.

pub const ARKUI_TEXT_MENU_ITEM_ID_ASK_AI: ArkUI_TextMenuItemId

Indicates the TextMenuItemId for asking AI.

pub const ARKUI_TEXT_MENU_ITEM_ID_APP_RESERVED_BEGIN: ArkUI_TextMenuItemId

Inclusive begin of app-reserved ID range.

pub const ARKUI_TEXT_MENU_ITEM_ID_APP_RESERVED_END: ArkUI_TextMenuItemId

Inclusive end of app-reserved ID range.