#[repr(transparent)]pub struct ArkUI_TextResponseType(pub c_uint);Available on crate features
api-12 and api-22 only.Expand description
Enumerates the text response type.
Available since API-level: 22
Tuple Fields
0: c_uintImplementations
Sourceimpl ArkUI_TextResponseType
impl ArkUI_TextResponseType
Sourcepub const ARKUI_TEXT_RESPONSE_TYPE_RIGHT_CLICK: ArkUI_TextResponseType
pub const ARKUI_TEXT_RESPONSE_TYPE_RIGHT_CLICK: ArkUI_TextResponseType
The response type of right click.
Sourcepub const ARKUI_TEXT_RESPONSE_TYPE_LONG_PRESS: ArkUI_TextResponseType
pub const ARKUI_TEXT_RESPONSE_TYPE_LONG_PRESS: ArkUI_TextResponseType
The response type of long press.
Sourcepub const ARKUI_TEXT_RESPONSE_TYPE_SELECT: ArkUI_TextResponseType
pub const ARKUI_TEXT_RESPONSE_TYPE_SELECT: ArkUI_TextResponseType
The response type of select by mouse.
Sourcepub const ARKUI_TEXT_RESPONSE_TYPE_DEFAULT: ArkUI_TextResponseType
pub const ARKUI_TEXT_RESPONSE_TYPE_DEFAULT: ArkUI_TextResponseType
When no other types are explicitly specified, this type will be matched. When this type is registered but RIGHT_CLICK, LONG_PRESS, or SELECT types are not registered, this type will be triggered and displayed for right-click, long press, and mouse selection actions.