ArkUI_TextSpanType

Struct ArkUI_TextSpanType 

#[repr(transparent)]
pub struct ArkUI_TextSpanType(pub c_uint);
Available on crate features api-12 and api-22 only.
Enumerates the text span type.

Available since API-level: 22

Tuple Fields

0: c_uint

Implementations

Source

impl ArkUI_TextSpanType

pub const ARKUI_TEXT_SPAN_TYPE_TEXT: ArkUI_TextSpanType

The span type only contains text.

pub const ARKUI_TEXT_SPAN_TYPE_IMAGE: ArkUI_TextSpanType

The span type only contains image.

pub const ARKUI_TEXT_SPAN_TYPE_MIXED: ArkUI_TextSpanType

The span type contains both text and image.

pub const ARKUI_TEXT_SPAN_TYPE_DEFAULT: ArkUI_TextSpanType

When no other types are explicitly specified, this type will be matched. When this type is registered but TEXT, IMAGE, or MIXED types are not registered, this type will be triggered and displayed for those registered types.