OH_ArkUI_AxisEvent_HasAxis

Function OH_ArkUI_AxisEvent_HasAxis 

pub unsafe extern "C" fn OH_ArkUI_AxisEvent_HasAxis(
    event: *const ArkUI_UIInputEvent,
    axis: i32,
) -> i32
Available on crate features api-12 and api-22 only.
Checks whether this axis event contains the specified axis type.

Arguments

  • event - Indicates the pointer to the current UI input event.

  • axis - Axis type of the axis event.

Returns

  • Whether the current axis event contains the specified axis type. Returns true if the axis event contains the specified axis type, and false otherwise.

Available since API-level: 22