OH_ArkUI_TouchTestInfoItem_GetChildRect

Function OH_ArkUI_TouchTestInfoItem_GetChildRect 

pub unsafe extern "C" fn OH_ArkUI_TouchTestInfoItem_GetChildRect(
    info: *const ArkUI_TouchTestInfoItem,
    childRect: *mut ArkUI_Rect,
) -> ArkUiResult
Available on crate features api-12 and api-22 only.
Obtains the sub component’s frame rect info from the touch test info item.

Arguments

  • info - Indicates the pointer to the touch test info item.

  • childRect - Indicates the pointer to the child frame rect.

Returns

  • Returns [ARKUI_ERROR_CODE_NO_ERROR] if success. Returns [ARKUI_ERROR_CODE_PARAM_INVALID] if a parameter exception occurs.

Available since API-level: 22