OH_ArkUI_TouchTestInfoItem_GetWindowY

Function OH_ArkUI_TouchTestInfoItem_GetWindowY 

pub unsafe extern "C" fn OH_ArkUI_TouchTestInfoItem_GetWindowY(
    info: *const ArkUI_TouchTestInfoItem,
) -> f32
Available on crate features api-12 and api-22 only.
Obtains the Y coordinate relative to the upper left corner of the current application window from the touch test info item.

Arguments

  • info - Indicates the pointer to the touch test info item.

Returns

  • Returns the Y coordinate relative to the upper left corner of the current application window. returns 0.0f if any parameter error occurs.

Available since API-level: 22