OH_ArkUI_TouchTestInfoItem_GetYRelativeToParent

Function OH_ArkUI_TouchTestInfoItem_GetYRelativeToParent 

pub unsafe extern "C" fn OH_ArkUI_TouchTestInfoItem_GetYRelativeToParent(
    info: *const ArkUI_TouchTestInfoItem,
) -> f32
Available on crate features api-12 and api-22 only.
Obtains the Y coordinate relative to the upper left corner of the parent component from the touch test info item.

Arguments

  • info - Indicates the pointer to the touch test info item.

Returns

  • Returns the Y coordinate relative to the upper left corner of the parent component. returns 0 if any parameter error occurs.

Available since API-level: 22