OH_ArkUI_TouchTestInfo_GetTouchTestInfoList

Function OH_ArkUI_TouchTestInfo_GetTouchTestInfoList 

pub unsafe extern "C" fn OH_ArkUI_TouchTestInfo_GetTouchTestInfoList(
    info: *mut ArkUI_TouchTestInfo,
    array: *mut ArkUI_TouchTestInfoItemArray,
    size: *mut i32,
) -> ArkUiResult
Available on crate features api-12 and api-22 only.
Obtains touch test info item list in the touch test info.

Arguments

  • info - Indicates the pointer to a touch test info.

  • array - Indicates the pointer to the array of touch test info list.

  • size - Indicates the size of the array of touch test info list.

Returns

  • Returns [ARKUI_ERROR_CODE_NO_ERROR] if success. Returns [ARKUI_ERROR_CODE_PARAM_INVALID] if a parameter exception occurs.

Available since API-level: 22