pub unsafe extern "C" fn OH_ArkUI_TouchTestInfo_SetTouchResultStrategy(
info: *mut ArkUI_TouchTestInfo,
strategy: ArkUI_TouchTestStrategy,
) -> ArkUiResultAvailable on crate features
api-12 and api-22 only.Expand description
Sets the touch test strategy, that is, how the component and the sub components behave during hit testing.
Arguments
{pointer} info Indicates the pointer to a touch test info.
{ArkUI_TouchTestStrategy} strategy The touch test strategy.
Returns
- Returns [
ARKUI_ERROR_CODE_NO_ERROR] if success. Returns [ARKUI_ERROR_CODE_PARAM_INVALID] if a parameter exception occurs.
Available since API-level: 22