pub unsafe extern "C" fn OH_ArkUI_UIInputEvent_GetCoastingAxisEvent(
event: *mut ArkUI_UIInputEvent,
) -> *mut ArkUI_CoastingAxisEventAvailable on crate features
api-12 and api-22 only.Expand description
Obtains the coasting axis event from a component event, valid event only can be
fetched only when user flings on the touchpad with two fingers and any components register
NODE_ON_COASTING_AXIS_EVENT exist under the pointer location.
Call this method after the ArkUI_UIInputEvent object is obtained from the [ArkUI_NodeEvent] object.
Arguments
event- Indicates the pointer to the UI input event.
Returns
- Returns the pointer to the coasting axis event, return null if no any coasting axis event occurs.
Available since API-level: 22