ArkUI_CoastingAxisEvent

Struct ArkUI_CoastingAxisEvent 

pub struct ArkUI_CoastingAxisEvent { /* private fields */ }
Available on crate features api-12 and api-22 only.
Defines the coasting axis event. When a user swipes with two fingers on the touchpad, the system constructs sliding events based on the speed at the moment the fingers are lifted according to a certain decay curve. You can listen for such events to handle the flick effect immediately after the regular axis events.

It only can be received when user flings on the touchpad with two fingers and any components register NODE_ON_COASTING_AXIS_EVENT through [registerNodeEvent] exist under the pointer location.

Available since API-level: 22