#[repr(transparent)]pub struct ArkUI_TouchTestStrategy(pub c_uint);Available on crate features
api-12 and api-22 only.Expand description
Define the touch test strategy.
Available since API-level: 22
Tuple Fields
0: c_uintImplementations
Sourceimpl ArkUI_TouchTestStrategy
impl ArkUI_TouchTestStrategy
Sourcepub const ARKUI_TOUCH_TEST_STRATEGY_DEFAULT: ArkUI_TouchTestStrategy
pub const ARKUI_TOUCH_TEST_STRATEGY_DEFAULT: ArkUI_TouchTestStrategy
Custom dispatch has no effect; the system distributes events based on the hit status of the current node.
Sourcepub const ARKUI_TOUCH_TEST_STRATEGY_FORWARD_COMPETITION: ArkUI_TouchTestStrategy
pub const ARKUI_TOUCH_TEST_STRATEGY_FORWARD_COMPETITION: ArkUI_TouchTestStrategy
The specified event is forwarded to a particular child node, and the system determines whether to distribute the event to other sibling nodes.
Sourcepub const ARKUI_TOUCH_TEST_STRATEGY_FORWARD: ArkUI_TouchTestStrategy
pub const ARKUI_TOUCH_TEST_STRATEGY_FORWARD: ArkUI_TouchTestStrategy
The specified event is forwarded to a particular child node, and the system no longer distributes the event to other sibling nodes.