#[repr(transparent)]pub struct HitTestMode(pub c_uint);api-12 only.Expand description
Enumerates the hit test modes.
Available since API-level: 12
Tuple Fields
0: c_uintImplementations
Sourceimpl HitTestMode
impl HitTestMode
Sourcepub const HTM_DEFAULT: HitTestMode
pub const HTM_DEFAULT: HitTestMode
Both the node and its child node respond to the hit test of a touch event, but its sibling node is blocked from the hit test.
Sourcepub const HTM_BLOCK: HitTestMode
pub const HTM_BLOCK: HitTestMode
The node responds to the hit test of a touch event, but its child node and sibling node are blocked from the hit test.
Sourcepub const HTM_TRANSPARENT: HitTestMode
pub const HTM_TRANSPARENT: HitTestMode
Both the node and its child node respond to the hit test of a touch event, and its sibling node is also considered during the hit test.
Sourcepub const HTM_NONE: HitTestMode
pub const HTM_NONE: HitTestMode
The node does not respond to the hit test of a touch event, but its child node and sibling node are considered during the hit test.
Sourcepub const HTM_BLOCK_HIERARCHY: HitTestMode
Available on crate feature api-20 only.
pub const HTM_BLOCK_HIERARCHY: HitTestMode
api-20 only.The node and its child nodes participate in hit tests, while blocking hit tests for all sibling nodes and parent nodes with lower priority.
Available since API-level: 20
Sourcepub const HTM_BLOCK_DESCENDANTS: HitTestMode
Available on crate feature api-20 only.
pub const HTM_BLOCK_DESCENDANTS: HitTestMode
api-20 only.The node does not respond to hit tests, and none of its descendants (including children and grandchildren) participate in hit tests either.
Available since API-level: 20