pub unsafe extern "C" fn OH_ArkUI_NativeModule_IsInRenderState(
node: ArkUI_NodeHandle,
isInRenderState: *mut bool,
) -> i32Available on crate features
api-12 and api-23 only.Expand description
Returns true if the node is in the render state. A node is considered to be in the render state if its corresponding RenderNode is on the render tree.
Arguments
-
node- ArkUI_NodeHandle pointer. -
isInRenderState- If the node is in the render state.
Returns
- Error code.
[
ARKUI_ERROR_CODE_NO_ERROR] if the operation is successful. [ARKUI_ERROR_CODE_PARAM_INVALID] Function parameter exception. [ARKUI_ERROR_CODE_CAPI_INIT_ERROR] if the CAPI init error.
Available since API-level: 23