pub unsafe extern "C" fn OH_ArkUI_Swiper_StopFakeDrag(
node: ArkUI_NodeHandle,
isSuccessful: *mut bool,
) -> i32Available on crate features
api-12 and api-23 only.Expand description
Stop a fake drag of the Swiper node.
Arguments
-
node- ArkUI_NodeHandle pointer. -
isSuccessful- If the fake drag stopped successfully, return true. If the Swiper is not ready to stop the fake drag, or no fake drag is in progress, return false.
Returns
- Error code.
[
ARKUI_ERROR_CODE_NO_ERROR] Success. [ARKUI_ERROR_CODE_PARAM_INVALID] Function parameter exception.
Available since API-level: 23