pub unsafe extern "C" fn OH_ArkUI_TouchTestInfo_SetTouchResultId(
info: *mut ArkUI_TouchTestInfo,
id: *const c_char,
) -> ArkUiResultAvailable on crate features
api-12 and api-22 only.Expand description
Sets the sub component’s name, that is, which sub components need to be effected during hit testing.
Arguments
{pointer} info Indicates the pointer to a touch test info.
{pointer} id The sub component’s name.
Returns
- Returns [
ARKUI_ERROR_CODE_NO_ERROR] if success. Returns [ARKUI_ERROR_CODE_PARAM_INVALID] if a parameter exception occurs.
Available since API-level: 22